@@ -367,6 +367,11 @@ class Microservices(BaseClass, ABC):
         # msg['metadata']['span'] if 'span' in msg['metadata'] else None
         rootSpan = None
 
+        if not msg.get('metadata', None) is None:
+            m = msg.get('metadata')
+            if not m.get('span', None) is None:
+                rootSpan = m.get('span')
+
         # Validar si es un smoktest
         if 'smoketest' in list(data):
             span = None
