@@ -2,7 +2,7 @@ import os
 import sys
 import re
 from .loggs import Loggs
-from .types import Types
+
 
 class Options:
     App = None
@@ -14,6 +14,7 @@ class Options:
     Legacy = False
     Logger = Loggs('Options')
     isNats = False
+
     def __init__(self, app, name, version, hosts, is_nats=False):
         """
             Clase para la construccion de las opciones del microservicio.
@@ -24,15 +25,16 @@ class Options:
             @params hosts Lista de direcciones de kafka o Nats.
             @params public Indicador si el servicio es de accesso publico
 
-            @returns void 
+            @returns void
         """
         # Validar que se pase la direccion de kafka de forma correcta
         if not isinstance(hosts, list):
-            self.Logger.error('No se proporciono una lista de direcciones de kafka correcta')
+            self.Logger.error(
+                'No se proporciono una lista de direcciones de kafka correcta')
             sys.exit(-1)
         elif len(hosts) < 1:
             self.Logger.error('Se proporciono una lista vacia de Kafka Hosts')
-        
+
         # Asignar la variable debug a verdadero si no es productivo.
         self.Debug = False if os.environ.get('PRODUCTION', False) else True
 
@@ -46,14 +48,12 @@ class Options:
         self.Version = version
 
         # Validar si es Nats
-        if os.environ.get('NATS', None) is None:
-            self.isNats = False
-        elif is_nats:
+        if os.environ.get('NATS', None) is not None:
             self.isNats = True
         elif len(re.findall(r'^nats.*', hosts[0])) > 0:
             self.isNats = True
         else:
-            self.isNats = True
+            self.isNats = False
 
         # Revalidar los brokers
         if len(os.environ.get('NATS', '')) > 0:
